﻿using System;
using System.Globalization;
using Windows.Data.Json;
using Windows.Devices.Geolocation;
using Windows.Foundation;
using Windows.UI.Popups;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.Web.Http;
using Windows.Services.Maps;
using Windows.UI.Xaml.Controls.Maps;


namespace Capabilities_1
{
    public sealed partial class MainPage : Page
    {
        public MainPage()
        {
            this.InitializeComponent();
            CultureInfo.CurrentCulture = new CultureInfo("en-en");
        }

        private async void Location_Click(object sender, RoutedEventArgs e)
        {
            var status = await Geolocator.RequestAccessAsync();

            if (status != GeolocationAccessStatus.Allowed)
            {
                await new MessageDialog($"Standorterkennung nicht möglich {status}").ShowAsync();
                return;
            }

            Geolocator geoloc = new Geolocator();
            Geoposition position = await geoloc.GetGeopositionAsync();

            lattitude.Text = position.Coordinate.Point.Position.Latitude.ToString();
            longitude.Text = position.Coordinate.Point.Position.Longitude.ToString();
        }

        private async void Find_Click(object sender, RoutedEventArgs e)
        {
            var lat = double.Parse(lattitude.Text);
            var lon = double.Parse(longitude.Text);

            // OpenStreetMap-Abfrage
            HttpClient httpClient = new HttpClient();
            var header = "SampleApp Windows 10";
            httpClient.DefaultRequestHeaders.UserAgent.TryParseAdd(header);

            var content = await httpClient.GetStringAsync(
                new Uri(new Uri("http://nominatim.openstreetmap.org"),
                  $"reverse?format=json&lat={lat}&lon={lon}"));

            JsonObject jsonObject = JsonObject.Parse(content);

            var address = "OpenStreetMap-Abfrage:\n";
            address += jsonObject.GetNamedString("display_name", "<na>");

            jsonObject = jsonObject.GetNamedObject("address");

            address += "\nLand: " + jsonObject.GetNamedString("country", "<na>");
            address += ", Plz: " + jsonObject.GetNamedString("postcode", "<na>");
            address += ", Strasse: " + jsonObject.GetNamedString("road", "<na>");
            address += ", Ort: " + jsonObject.GetNamedString("city", "<na>");

            address += "\n\nUniversal Windows Platform-Abfrage:\n";
            var position = new BasicGeoposition()
            {
                Latitude = lat,
                Longitude = lon
            };

            var geopoint = new Geopoint(position);
            var location = await MapLocationFinder.FindLocationsAtAsync(geopoint);
            if (location.Status == MapLocationFinderStatus.Success)
            {
                foreach (var loc in location.Locations)
                {
                    address += loc.Address.FormattedAddress + "\n";
                }
            }

            textblock.Text = address;

            // Standort in Karte anzeigen und zoomen
            MapIcon pointOfInterest = new MapIcon
            {
                Location = geopoint,
                NormalizedAnchorPoint = new Point(0.5, 1.0),
                Title = "Interessanter Punkt",
                ZIndex = 0
            };

            map.MapElements.Add(pointOfInterest);
            
            //map.Center = geopoint;
            //map.ZoomLevel = 14;
            await map.TrySetViewAsync(geopoint, 14, null, null, MapAnimationKind.Bow);
        }

        private void map_MapTapped(MapControl sender, MapInputEventArgs args)
        {
            lattitude.Text = args.Location.Position.Latitude.ToString();
            longitude.Text = args.Location.Position.Longitude.ToString();
        }

        private void aerial_UnChecked(object sender, RoutedEventArgs e)
        {
            map.Style = aerial.IsChecked == true ? MapStyle.Aerial : MapStyle.Road;
        }
    }
}
